<?php

class MDHQCRelayMembershipNotifications {

	/**
	 * Init Plugin
	 */
	public function __construct() {
		/**
		 * Fires after a user has been granted membership access.
		 *
		 * This hook is similar to `wc_memberships_user_membership_created`,
		 * but will also fire when a membership is manually created in admin,
		 * or upon an import or via command line interface, etc.
		 * @see \wc_memberships_create_user_membership()
		 *
		 * @since 1.3.8
		 *
		 * @param \WC_Memberships_Membership_Plan $membership_plan the plan that user was granted access to.
		 * @param array $args
		 * @param array $args array of contextual arguments {
		 *     @type int $user_id the user ID the membership is assigned to.
		 *     @type int $user_membership_id the user membership id being saved.
		 *     @type bool $is_update whether this is a post update or a newly created membership.
		 * }
		 */
		add_action( 'wc_memberships_user_membership_saved', array( $this, 'notification' ), 10, 2 );
	}
	
	public function notification( $membership_plan, $args ) {
		if (function_exists('get_current_screen')) {
                $wp_screen = get_current_screen();

                /**
                 * Don't send if we are loading the new membership screen
                 * Only send when clicked on save or creating from php
                 */
                if ( 'add' == $wp_screen->action ) {
                    return;
                }
            }

		/**
		 * Don't send if we are updating an existing membership
		 */
		if ( isset( $_POST['original_post_status'] ) && 'auto-draft' != $_POST['original_post_status'] ) {
			return;
		}

        /**
         * Don't send if we are updating an existing membership
         */
        if (!empty($args['is_update'])) {
            return;
        }

		$userdata = get_userdata( $args['user_id'] );
        $site_url = get_site_url();
        $site_name = get_bloginfo( 'name' );
        $admin_email = get_option('admin_email');
		$tags = array(
			'username' => $userdata->user_login,
			'email' => $userdata->user_email,
			'first_name' => get_user_meta( $args['user_id'], 'first_name', true ),
			'last_name' => get_user_meta( $args['user_id'], 'last_name', true ),
			'provider' => '',
			'access_code' => '',
			'1click_login' => '<a href="'. $site_url .'/my-account/?nrlogin=' . get_user_meta( $args['user_id'], 'nr_link', true ) . '">Click to login</a>',
		);

		$memberships = get_option( 'as_wc_membership_options' );
		foreach ( $memberships as $membership ) {
			if ( intval( $membership['casePlan'] ) === intval( $membership_plan->id ) ) {
				$tags['provider'] = $membership['caseOption'];
				$tags['access_code'] = $membership['caseAccess'];
				break;
			}
		}

		$headers = "Content-type: text/html\r\n"
			. "From: ". $site_name ." <". $admin_email .">";
		
		$sent = false;

        $membershipTemplates = get_option('mdhqd_membership_mails');
        if (empty($membershipTemplates)) {
            return;
        }
        $membershipTemplates = json_decode($membershipTemplates, true);
        if (empty($membershipTemplates)) {
            return;
        }
        $defaultTemplate = [];
        $templateToSend = [];
        foreach ($membershipTemplates as $membershipTemplate) {
            if ($membershipTemplate['code'] === $tags['access_code']) {
                $templateToSend = $membershipTemplate;
            }

            if (strtolower($membershipTemplate['code']) === 'default') {
                $defaultTemplate = $membershipTemplate;
            }
        }

        if (empty($templateToSend)) {
            if (empty($defaultTemplate)) {
                return;
            }
            $templateToSend = $defaultTemplate;
        }

        $message = $templateToSend['message'];
        foreach ( $tags as $key => $val ) {
            $message = str_replace( "[$key]", $val, $message );
        }
        $subject = $templateToSend['subject'];
        foreach ( $tags as $key => $val ) {
            $subject = str_replace( "[$key]", $val, $subject );
        }
        wp_mail(
            $tags['email'],
            $subject,
            $message,
            $headers
        );
	}

}

$wc_memberships_notifications = new MDHQCRelayMembershipNotifications();
